context("canvasXpress Web Charts - Waterfall")


test_that("cXwaterfall1", {
    check_ui_test(cXwaterfall1())
})

test_that("cXwaterfall2", {
    check_ui_test(cXwaterfall2())
})

test_that("cXwaterfall3", {
    check_ui_test(cXwaterfall3())
})

test_that("cXwaterfall4", {
    check_ui_test(cXwaterfall4())
})

test_that("cXwaterfall5", {
    check_ui_test(cXwaterfall5())
})
